changeset 3766:848492e2aafa beta

h.person, if author name is empty, use email as a fallback
author Marcin Kuzminski <marcin@python-works.com>
date Tue, 16 Apr 2013 01:42:24 +0200
parents 5a8918aba869
children e203cd3640db
files rhodecode/lib/helpers.py
diffstat 1 files changed, 2 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/rhodecode/lib/helpers.py	Tue Apr 16 00:59:14 2013 +0200
+++ b/rhodecode/lib/helpers.py	Tue Apr 16 01:42:24 2013 +0200
@@ -456,8 +456,8 @@
     if user is not None:
         return person_getter(user)
 
-    # Still nothing?  Just pass back the author name then
-    return _author
+    # Still nothing?  Just pass back the author name if any, else the email
+    return _author or _email
 
 
 def person_by_id(id_, show_attr="username_and_name"):